@@ -1,5 +1,121 @@
 package Algorithm::Dependency::Source;
 
+# Algorithm::Dependency::Source implements a parent class for a source
+# of items.
+
+use 5.005;
+use strict;
+use Algorithm::Dependency;
+
+use vars qw{$VERSION};
+BEGIN {
+	$VERSION = '1.01';
+}
+
+
+
+
+
+sub new {
+	my $class = shift;
+
+	# This can't be created directly, it must be through
+	# a SUPER::new call
+	if ( $class eq __PACKAGE__ ) {
+		die "Cannot directly instantiate Algorithm::Dependency::Source. You must use a subclass";
+	}
+
+	# Create the basic object
+	bless {
+		# Has the source been loaded
+		loaded      => 0,
+
+		# Indexes
+		items_hash  => undef,
+		items_array => undef,
+		}, $class;
+}
+
+# Load the source
+sub load {
+	my $self = shift;
+	my $class = ref $self;
+
+	# If this is a reload, clean up in preperation
+	if ( $self->{loaded} ) {
+		$self->{loaded} = 0;
+		$self->{items_hash} = undef;
+		$self->{items_array} = undef;
+	}
+
+	# Pass through to the real loader
+	my $items = $self->_load_item_list;
+	return $items unless $items;
+	return undef unless UNIVERSAL::isa( $items, 'ARRAY' );
+
+	# Add the items
+	foreach my $item ( @$items ) {
+		unless ( UNIVERSAL::isa( $item, 'Algorithm::Dependency::Item' ) ) {
+			die "$class\::_load_item_list returned something that was not an Algorithm::Dependency::Item";
+		}
+
+		# Have we added this one already?
+		my $id = $item->id;
+		if ( $self->{items_hash}->{ $id } ) {
+			# Duplicate entry
+			return undef;
+		}
+
+		# Add it
+		push @{ $self->{items_array} }, $item;
+		$self->{items_hash}->{$id} = $item;
+	}
+
+	$self->{loaded} = 1;
+}
+
+# Get a single item by id
+sub item {
+	my $self = shift;
+	my $id = length $_[0] ? shift : return undef;
+	$self->{loaded} or $self->load or return undef;
+
+	# Return the item ( or undef )
+	$self->{items_hash}->{$id};
+}
+
+# Get a list of the items
+sub items {
+	my $self = shift;
+	$self->{loaded} or $self->load or return undef;
+	@{ $self->{items_array} };
+}
+
+# Check the integrity of the source.
+sub missing_dependencies {
+	my $self = shift;
+	$self->{loaded} or $self->load or return undef;
+	
+	# Merged the depends of all the items, and see if
+	# any are missing.
+	my %missing = map { $_ => 1 } grep { ! exists $self->{items_hash}->{$_} }
+		map { $_->depends } @{ $self->{items_array} };
+	%missing ? [ sort keys %missing ] : 0;
+}
+
+
+
+
+
+#####################################################################
+# Catch methods our subclass should define but didn't
+
+sub _load_item_list { die "Class $_[0] failed to define the method _load_item_list" };
+
+1;
+
+__END__
+
 =pod
 
 =head1 NAME
@@ -16,27 +132,6 @@ L<Algorithm::Dependency> package.
 
 =head1 METHODS
 
-=cut
-
-use 5.005;
-use strict;
-use Algorithm::Dependency ();
-use Params::Util qw{_SET};
-
-use vars qw{$VERSION};
-BEGIN {
-	$VERSION = '1.105_01';
-}
-
-
-
-
-
-#####################################################################
-# Constructor
-
-=pod
-
 =head2 new @arguments
 
 Although you cannot directly use the C<new> constructor for
@@ -50,33 +145,6 @@ until you need to use the items.
 
 Returns a new object on success, or C<undef> on error.
 
-=cut
-
-sub new {
-	my $class = shift;
-
-	# This can't be created directly, it must be through
-	# a SUPER::new call
-	if ( $class eq __PACKAGE__ ) {
-		die "Cannot directly instantiate Algorithm::Dependency::Source."
-			. " You must use a subclass";
-	}
-
-	# Create the basic object
-	my $self = bless {
-		# Has the source been loaded
-		loaded      => 0,
-
-		# Indexes
-		items_hash  => undef,
-		items_array => undef,
-		}, $class;
-
-	$self;
-}
-
-=pod
-
 =head2 load
 
 The C<load> method is the public method used to actually load the items from
@@ -87,44 +155,6 @@ that the source will load correctly, and want to check it will work.
 
 Returns true if the items are loaded successfully, or C<undef> on error.
 
-=cut
-
-sub load {
-	my $self = shift;
-
-	# If this is a reload, clean up in preperation
-	if ( $self->{loaded} ) {
-		$self->{loaded}      = 0;
-		$self->{items_hash}  = undef;
-		$self->{items_array} = undef;
-	}
-
-	# Pass through to the real loader
-	my $items = $self->_load_item_list;
-	return $items unless $items;
-	unless ( _SET($items, 'Algorithm::Dependency::Item') ) {
-		die( ref($self) . "::_load_item_list did not return an Algorithm::Dependency::Item set" );
-	}
-
-	# Add the items
-	foreach my $item ( @$items ) {
-		# Have we added this one already?
-		my $id = $item->id;
-		if ( $self->{items_hash}->{ $id } ) {
-			# Duplicate entry
-			return undef;
-		}
-
-		# Add it
-		push @{ $self->{items_array} }, $item;
-		$self->{items_hash}->{$id} = $item;
-	}
-
-	$self->{loaded} = 1;
-}
-
-=pod
-
 =head2 item $name
 
 The C<item> method fetches and returns the item object specified by the
@@ -133,19 +163,6 @@ name argument.
 Returns an L<Algorithm::Dependency::Item> object on success, or C<undef> if
 the named item does not exist in the source.
 
-=cut
-
-sub item {
-	my $self = shift;
-	my $id   = (defined $_[0] and ! ref $_[0] and $_[0] ne '') ? shift : return undef;
-	$self->{loaded} or $self->load or return undef;
-
-	# Return the item (or undef)
-	$self->{items_hash}->{$id};
-}
-
-=pod
-
 =head2 items
 
 The C<items> method returns, as a list of objects, all of the items
@@ -155,16 +172,6 @@ as that in the storage location.
 Returns a list of L<Algorithm::Dependency::Item> objects on success, or
 C<undef> on error.
 
-=cut
-
-sub items {
-	my $self = shift;
-	$self->{loaded} or $self->load or return undef;
-	@{ $self->{items_array} };
-}
-
-=pod
-
 =head2 missing_dependencies
 
 By default, we are leniant with missing dependencies if the item is neved 
@@ -176,41 +183,11 @@ If there are any missing dependencies, returns a reference to an array of
 their ids. If there are no missing dependencies, returns 0. Returns 
 C<undef> on error.
 
-=cut
-
-sub missing_dependencies {
-	my $self = shift;
-	$self->{loaded} or $self->load or return undef;
-	
-	# Merged the depends of all the items, and see if
-	# any are missing.
-	my %missing = map  { $_ => 1           }
-	              grep { ! $self->item($_) }
-	              map  { $_->depends       }
-	              $self->items;
-	%missing ? [ sort keys %missing ] : 0;
-}
-
-
-
-
-
-#####################################################################
-# Catch unimplemented methods in subclasses
-
-sub _load_item_list {
-	die "Class $_[0] failed to define the method _load_item_list";
-}
-
-1;
-
-=pod
-
 =head1 EXTENDING
 
-C<Algorithm::Dependency::Source> itself is a fairly thin module, and it
-is intended that you will probably need to extend it to be able to
-extract item data from whatever location you have stored them.
+Algorithm::Dependency::Source itself is a fairly thin module, and it is
+intended that you will probably need to extend it to be able to extract
+item data from whatever location you have stored them.
 
 This is usually a fairly simple two step process.
 
@@ -242,11 +219,11 @@ For general comments, contact the author.
 To file a bug against this module, in a way you can keep track of, see the
 CPAN bug tracking system.
 
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Algorithm-Dependency>
+http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Algorithm%3A%3ADependency
 
 =head1 AUTHOR
 
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>, L<http://ali.as/>
+Adam Kennedy (Maintainer), L<http://ali.as/>, cpan@ali.as
 
 =head1 SEE ALSO
 
@@ -254,8 +231,7 @@ L<Algorithm::Dependency>, L<Algorithm::Dependency::Source::File>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2003 - 2005 Adam Kennedy.
-
+Copyright (c) 2003 Adam Kennedy. All rights reserved.
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
 
